History
*******



NetworkX = Network "X"  = NX (for short)

Original Creators::

	 Aric Hagberg, hagberg@lanl.gov
	 Pieter Swart, swart@lanl.gov
         Dan Schult, dschult@colgate.edu


.. toctree::
   :maxdepth: 2

   api_changes
   news
